from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import String, File, Int, Boolean, Float

Pourrna_V0_1_0 = CommandToolBuilder(tool="pourRNA", base_command=["pourRNA"], inputs=[ToolInput(tag="in_sequence", input_type=String(optional=True), prefix="--sequence", doc=InputDocumentation(doc="The RNA sequence of the molecule\n(default=`ACUGUAUGCGCGU')")), ToolInput(tag="in_start_structure", input_type=String(optional=True), prefix="--start-structure", doc=InputDocumentation(doc="the start structure of the exploration defining\nthe first gradient basin; defaults to the\nopen chain")), ToolInput(tag="in_start_structure_file", input_type=File(optional=True), prefix="--start-structure-file", doc=InputDocumentation(doc="File with start structures (one per line)")), ToolInput(tag="in_final_structure", input_type=String(optional=True), prefix="--final-structure", doc=InputDocumentation(doc="the final structure of the exploration defining\nthe last gradient basin")), ToolInput(tag="in_max_threads", input_type=Int(optional=True), prefix="--max-threads", doc=InputDocumentation(doc="Sets the maximum number of threads for\nparallelized computation.")), ToolInput(tag="in_skip_diagonal", input_type=Boolean(optional=True), prefix="--skip-diagonal", doc=InputDocumentation(doc="Skip the computation of the diagonal of the\nrate matrix (it can be skipped because some\npost-processing tools like treekin compute it\nper default).  (default=off)")), ToolInput(tag="in_filter_best_k", input_type=Int(optional=True), prefix="--filter-best-k", doc=InputDocumentation(doc="reduces outgoing transitions to the best K for\neach gradient basin")), ToolInput(tag="in_dynamic_best_k", input_type=Boolean(optional=True), prefix="--dynamic-best-k", doc=InputDocumentation(doc="Increases K if the MFE structure is not")), ToolInput(tag="in_max_neigh_e", input_type=Int(optional=True), prefix="--max-neigh-e", doc=InputDocumentation(doc="reduces outgoing transitions to the neighbored\nminima, for which the energy is lower than\nthe energy of the current minimum plus the\nfilter value. (E(neighbored minimum) <\nE(current minimum) + filterValue) for each\ngradient basin.")), ToolInput(tag="in_max_to_queue", input_type=Int(optional=True), prefix="--max-to-queue", doc=InputDocumentation(doc="Sets the maximum number of states to be stored\nin the priority queue of the flooder.")), ToolInput(tag="in_max_to_hash", input_type=Int(optional=True), prefix="--max-to-hash", doc=InputDocumentation(doc="Sets the maximum number of states to be hashed\nfor a gradient walk.")), ToolInput(tag="in_dynamic_max_to_hash", input_type=Boolean(optional=True), prefix="--dynamic-max-to-hash", doc=InputDocumentation(doc="Sets the dynamicMaxToHash variable for\nestimating the maximal number of states to be\nhashed in a gradient walk, by considering the\nmaximal available physical memory and the\nnumber of threads. This reduces the\nprobability of swapping.\n(default=off)")), ToolInput(tag="in_max_energy", input_type=Int(optional=True), prefix="--max-energy", doc=InputDocumentation(doc="Sets the maximum energy that a state is allowed\nto have to be considered by the flooder (in\nkcal/mol).\n(default=`5')")), ToolInput(tag="in_delta_e", input_type=Int(optional=True), prefix="--delta-e", doc=InputDocumentation(doc="Set the maximum energy difference that states\nin a basin can have w.r.t. the local minimum\n(in kcal/mol).\n(default=`65536')")), ToolInput(tag="in_max_bp_dist_add", input_type=Int(optional=True), prefix="--max-bp-dist-add", doc=InputDocumentation(doc="Increases the maximum base pair distance for\ndirect neighbor minima to be explored. Needs\na start structure and a final structure in\norder to work. For all discovered minima m\nholds: bp_dist(m, start-structure) +\nbp_dist(m, final-structure) <\nd(start-structure, final-structure) +\nmaxBPdist_add.\nIf this parameter is given, the explorative\nflooding will not stop at the final\nstructure! Instead\nit will explore all minima on the direct path\nand at its borders. This helps to evaluate\noptimal refolding paths\nin a post-processing step.\n(default=`65536')")), ToolInput(tag="in_temperature", input_type=Int(optional=True), prefix="--temperature", doc=InputDocumentation(doc="Set the temperature for the free energy\ncalculation (in °C). (If 'T' is set and\n'B' not, 'B' is equals 'T').\n(default=`37')")), ToolInput(tag="in_gas_constant", input_type=Float(optional=True), prefix="--gas-constant", doc=InputDocumentation(doc="Set the gas constant in [kcal/(K*mol)]. You\nneed this in order to compare the rate matrix\nwith the results of other tools.\nViennaRNA package: 0.00198717 kcal/(K*mol)\nBarriers:          0.00198717 kcal/(K*mol)\nELL Library:       0.0019871588 kcal/(K*mol)\n(default=`0.00198717')")), ToolInput(tag="in_dangling_end", input_type=Int(optional=True), prefix="--dangling-end", doc=InputDocumentation(doc="How to treat 'dangling end' energies for\nbases adjacent to helices in free ends and\nmulti-loops.\n(default=`2')")), ToolInput(tag="in_boltzmann_temp", input_type=Int(optional=True), prefix="--boltzmann-temp", doc=InputDocumentation(doc="Set the temperature for the Boltzmann weight\n(in °C).\n(default=`37')")), ToolInput(tag="in_energy_model", input_type=Int(optional=True), prefix="--energy-model", doc=InputDocumentation(doc="Set the energy model. 0=Turner model 2004,\n1=Turner model 1999, 2=Andronescu model, 2007\n(default=`0')")), ToolInput(tag="in_move_set", input_type=Int(optional=True), prefix="--move-set", doc=InputDocumentation(doc="Move set: 0 = insertion and deletion, 1 = shift\nmoves, 2 = no lonely pair moves.\n(default=`0')")), ToolInput(tag="in_transition_prob", input_type=File(optional=True), prefix="--transition-prob", doc=InputDocumentation(doc="If provided, the transition probability matrix\nwill be written to the given file name or\n'STDOUT' when to write to standard output")), ToolInput(tag="in_energy_file", input_type=File(optional=True), prefix="--energy-file", doc=InputDocumentation(doc="File to store all energies.")), ToolInput(tag="in_binary_rates_file", input_type=File(optional=True), prefix="--binary-rates-file", doc=InputDocumentation(doc="File to store all rates in a treekin readable\nformat.")), ToolInput(tag="in_binary_rates_file_sparse", input_type=File(optional=True), prefix="--binary-rates-file-sparse", doc=InputDocumentation(doc="File to store all rates in a sparse binary\nformat: First value is the number of states\n(uint_32), then <uint_32 from>, <uint_32\nnumber of how many value pairs to>, <value\npair <uint_32 to, double rate from, to>> etc.")), ToolInput(tag="in_saddle_file", input_type=File(optional=True), prefix="--saddle-file", doc=InputDocumentation(doc="Store all saddles in a CSV file.")), ToolInput(tag="in_barriers_like_output", input_type=File(optional=True), prefix="--barriers-like-output", doc=InputDocumentation(doc="Output the rates file and the structures in a\nformat similar to the tool barriers. For the\nsame prefix is used for both files.")), ToolInput(tag="in_partition_functions", input_type=File(optional=True), prefix="--partition-functions", doc=InputDocumentation(doc="If provided, the partition function matrix will\nbe written to the given file name.")), ToolInput(tag="in_dot_plot", input_type=File(optional=True), prefix="--dot-plot", doc=InputDocumentation(doc="If provided, the dotPlot will be written to the\ngiven file name. The dotPlot contains the\nbase pair probabilities for all structures in\nthe (filtered) energy landscape.")), ToolInput(tag="in_dot_plot_per_basin", input_type=String(optional=True), prefix="--dot-plot-per-basin", doc=InputDocumentation(doc="Creates a dotplot for each gradient basin in\nthe enrgy landscape. It shows the Maximum\nExpected Accuracy (MEA) structure in the\nupper right triangle and the basin\nrepresentative in the lower left triangle.")), ToolInput(tag="in_verbose", input_type=Boolean(optional=True), prefix="--verbose", doc=InputDocumentation(doc="Verbose.\n(default=off)\n")), ToolInput(tag="in_explored_dot", input_type=String(), position=0, doc=InputDocumentation(doc="(default=off)"))], outputs=[ToolOutput(tag="out_transition_prob", output_type=File(optional=True), selector=InputSelector(input_to_select="in_transition_prob", type_hint=File()), doc=OutputDocumentation(doc="If provided, the transition probability matrix\nwill be written to the given file name or\n'STDOUT' when to write to standard output")), ToolOutput(tag="out_barriers_like_output", output_type=File(optional=True), selector=InputSelector(input_to_select="in_barriers_like_output", type_hint=File()), doc=OutputDocumentation(doc="Output the rates file and the structures in a\nformat similar to the tool barriers. For the\nsame prefix is used for both files."))], container=None, version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Pourrna_V0_1_0().translate("wdl", allow_empty_container=True)

